@@ -121,9 +121,11 @@ class WowApi(object):
             logger.info('Fetching access token..')
             self._get_client_credentials(region)
         else:
-            now = datetime.utcnow()
-            # refresh access token if expired
-            if now >= self._access_tokens[region]['expiration']:
+            now = self._utcnow()
+            # refresh access token if expiring in the next 30 seconds.
+            # this protects against the rare occurrence of hitting
+            # the API right as your token expires, causing errors.
+            if now >= self._access_tokens[region]['expiration'] - timedelta(seconds=30):
                 logger.info('Access token expired. Fetching new token..')
                 self._get_client_credentials(region)
 
